@@ -21,18 +21,21 @@ import java.util.Optional;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 import java.util.function.Predicate;
+
 import javax.annotation.PostConstruct;
+import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
-import com.google.gwt.user.cellview.client.ColumnSortList;
 import com.google.gwt.view.client.Range;
 import org.dashbuilder.dataset.client.DataSetReadyCallback;
 import org.dashbuilder.dataset.filter.ColumnFilter;
+import org.dashbuilder.dataset.filter.CoreFunctionFilter;
 import org.dashbuilder.dataset.sort.SortOrder;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jbpm.workbench.common.client.dataset.ErrorHandlerBuilder;
 import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
+import org.jbpm.workbench.common.client.filters.active.ClearAllActiveFiltersEvent;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterAddEvent;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterRemoveEvent;
 import org.jbpm.workbench.common.client.filters.saved.SavedFilterSelectedEvent;
@@ -64,6 +67,8 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
     @Inject
     protected DefaultWorkbenchErrorCallback errorCallback;
 
+    protected Event<ClearAllActiveFiltersEvent> clearAllActiveFiltersEvent;
+
     protected ManagedInstance<ErrorHandlerBuilder> errorHandlerBuilder;
 
     @Inject
@@ -81,6 +86,11 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
         this.dataSetQueryHelper = dataSetQueryHelper;
     }
 
+    @Inject
+    public void setClearAllActiveFiltersEvent(Event<ClearAllActiveFiltersEvent> clearAllActiveFiltersEvent) {
+        this.clearAllActiveFiltersEvent = clearAllActiveFiltersEvent;
+    }
+
     public void setFilterSettingsManager(final FilterSettingsManager filterSettingsManager) {
         this.filterSettingsManager = filterSettingsManager;
     }
@@ -104,11 +114,9 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
         this.view = view;
     }
 
-    public void setupActiveSearchFilters() {
-        setupDefaultActiveSearchFilters();
-    }
+    public abstract void setupActiveSearchFilters();
 
-    public abstract void setupDefaultActiveSearchFilters();
+    public abstract boolean existActiveSearchFilters();
 
     @PostConstruct
     public void init() {
@@ -121,11 +129,16 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
     @OnOpen
     public void onOpen() {
         super.onOpen();
-        setFilterSettings(filterSettingsManager.createDefaultFilterSettingsPrototype(),
-                          table -> {
-                              setupActiveSearchFilters();
-                              addDataDisplay(table);
-                          });
+        if (existActiveSearchFilters()) {
+            clearAllActiveFiltersEvent.fire(new ClearAllActiveFiltersEvent());
+            setFilterSettings(filterSettingsManager.createDefaultFilterSettingsPrototype(),
+                              table -> {
+                                  setupActiveSearchFilters();
+                                  addDataDisplay(table);
+                              });
+        } else {
+            filterSettingsManager.defaultActiveFilterInit(filterSettings -> addActiveFilters(filterSettings));
+        }
     }
 
     public Predicate<String> getFilterEventPredicate() {
@@ -154,11 +167,24 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
                                                 filter -> addActiveFilters(filter));
     }
 
-    protected void setFilterSettings(final FilterSettings filter,
-                                     final Consumer<ListTable<T>> readyCallback) {
+    protected void setFilterSettings(final FilterSettings filter, final Consumer<ListTable<T>> readyCallback) {
         getDataSetQueryHelper().setCurrentTableSettings(filter);
-        view.loadListTable(filter.getKey(),
-                           readyCallback);
+        view.loadListTable(filter.getKey(), readyCallback);
+    }
+
+    public ActiveFilterItem getActiveFilterFromColumnFilter(ColumnFilter columnFilter) {
+        String labelValue = columnFilter.toString();
+        if (columnFilter instanceof CoreFunctionFilter) {
+            labelValue = ((CoreFunctionFilter) columnFilter).getLabelValue();
+            if (labelValue == null || labelValue.isEmpty()) {
+                labelValue = columnFilter.toString();
+            }
+        }
+        return new ActiveFilterItem<>(columnFilter.getColumnId(),
+                                      labelValue,
+                                      null,
+                                      null,
+                                      v -> removeActiveFilter(columnFilter));
     }
 
     protected void addActiveFilters(final FilterSettings filter) {
@@ -168,11 +194,7 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
                               if (filter.getDataSetLookup().getFirstFilterOp() != null) {
                                   List<ColumnFilter> filters = filter.getDataSetLookup().getFirstFilterOp().getColumnFilterList();
                                   filters.forEach(column -> {
-                                      final ActiveFilterItem activeFilter = new ActiveFilterItem<>(column.getColumnId(),
-                                                                                                   column.toString(),
-                                                                                                   null,
-                                                                                                   null,
-                                                                                                   v -> removeActiveFilter(column));
+                                      final ActiveFilterItem activeFilter = getActiveFilterFromColumnFilter(column);
                                       view.addActiveFilter(activeFilter);
                                   });
                               }
@@ -186,17 +208,19 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
             final FilterSettings currentTableSettings = getDataSetQueryHelper().getCurrentTableSettings();
             currentTableSettings.setServerTemplateId(getSelectedServerTemplate());
             currentTableSettings.setTablePageSize(view.getListGrid().getPageSize());
-            ColumnSortList columnSortList = view.getListGrid().getColumnSortList();
-            if (columnSortList != null && columnSortList.size() > 0) {
-                getDataSetQueryHelper().setLastOrderedColumn(columnSortList.size() > 0 ? columnSortList.get(0).getColumn().getDataStoreName() : "");
-                getDataSetQueryHelper().setLastSortOrder(columnSortList.size() > 0 && columnSortList.get(0).isAscending() ? SortOrder.ASCENDING : SortOrder.DESCENDING);
+
+            final String sortColumn = view.getSortColumn();
+            final Boolean sortAscending = view.isSortAscending();
+            if (sortColumn != null) {
+                getDataSetQueryHelper().setLastOrderedColumn(sortColumn);
+                getDataSetQueryHelper().setLastSortOrder(sortAscending ? SortOrder.ASCENDING : SortOrder.DESCENDING);
             }
 
             getDataSetQueryHelper().setCurrentTableSettings(currentTableSettings);
             getDataSetQueryHelper().setDataSetHandler(currentTableSettings);
             getDataSetQueryHelper().lookupDataSet(visibleRange.getStart(),
-                                             getDataSetReadyCallback(visibleRange.getStart(),
-                                                                     currentTableSettings));
+                                                  getDataSetReadyCallback(visibleRange.getStart(),
+                                                                          currentTableSettings));
         } catch (Exception e) {
             errorCallback.error(e);
             setEmptyResults();
@@ -278,4 +302,4 @@ public abstract class AbstractMultiGridPresenter<T extends GenericSummary, V ext
     public Predicate<T> getViewErrorsActionCondition() {
         return null;
     }
-}
\ No newline at end of file
+}
